@@ -27,7 +27,14 @@ class JourneySectionPrivate;
 class RentalVehicle;
 class Stopover;
 
-/** A segment of a journey plan. */
+/** A segment of a journey plan.
+ *
+ *  Also used for trips, ie. a single full vehicle run along a route.
+ *
+ *  This consists of a departure and an arrival stopover as well as zero or more intermediate stopovers.
+ *  For extracting sub-journeys those can be addresses by a numeric index. Index 0 refers to the departure,
+ *  1 to N refer to the n-th intermediate stopover and N + 1 refers to the arrival, for N intermediate stops.
+ */
 class KPUBLICTRANSPORT_EXPORT JourneySection
 {
     KPUBLICTRANSPORT_GADGET(JourneySection)
@@ -129,7 +136,7 @@ public:
     /** Vehicle load information for this journey section.
      *  Contains LoadInfo objects for consumption by QML.
      */
-    Q_PROPERTY(QVariantList loadInformation READ loadInformationVariant STORED false)
+    Q_PROPERTY(QList<KPublicTransport::LoadInfo> loadInformation READ loadInformationList WRITE setLoadInformationList STORED false)
 
     /** Information about a rental vehicle, for sections using one. */
     KPUBLICTRANSPORT_PROPERTY(KPublicTransport::RentalVehicle, rentalVehicle, setRentalVehicle)
@@ -166,6 +173,12 @@ public:
      */
     Q_PROPERTY(QString iconName READ iconName STORED false)
 
+    /** Label shortly describing this transport for display. */
+    Q_PROPERTY(QString label READ label STORED false)
+
+    /** Maximum occpancy over all classes. */
+    Q_PROPERTY(KPublicTransport::Load::Category maximumOccupancy READ maximumOccupancy STORED false)
+
 public:
     [[nodiscard]] bool hasExpectedDepartureTime() const;
     [[nodiscard]] int departureDelay() const;
@@ -258,9 +271,43 @@ public:
      */
     Q_INVOKABLE [[nodiscard]] static QString modeIconName(KPublicTransport::JourneySection::Mode mode);
 
+    [[nodiscard]] QString label() const;
+    [[nodiscard]] Load::Category maximumOccupancy() const;
+
+    /** Backend-specific journey section identifiers. */
+    [[nodiscard]] QString identifier(QAnyStringView identifierType) const;
+    [[nodiscard]] bool hasIdentifier(QAnyStringView identifierType) const;
+    void setIdentifier(const QString &identifierType, const QString &id);
+    /** Returns @c true if there is any identifier set at all.
+     *  This is usually a prerequisite for efficient trip queries.
+     */
+    [[nodiscard]] bool hasIdentifiers() const;
+
+    /** Retrieve stopover at index @p idx. */
+    [[nodiscard]] Stopover stopover(qsizetype idx) const;
+    /** Set the stopover at index @p idx.
+     *  If @p idx is not a valid index nothing is done.
+     */
+    void setStopovver(qsizetype idx, const Stopover &stop);
+
+    /** Returns the index of @p stop in this journey section.
+     *  @returns -1 if @p stop isn't found.
+     */
+    [[nodiscard]] qsizetype indexOfStopover(const Stopover &stop) const;
+
+    /** Returns the sub-journey starting from index @p begin until
+     *  @p end (inclusive).
+     *
+     *  Both @p begin and @p end have to be valid indices and @p end has to
+     *  be strictly larger than @p begin, otherwise an invalid journey section
+     *  is returned.
+     */
+    [[nodiscard]] JourneySection subsection(qsizetype begin, qsizetype end) const;
+
 private:
-    [[nodiscard]] QVariantList intermediateStopsVariant() const;
-    [[nodiscard]] QVariantList loadInformationVariant() const;
+    [[nodiscard]] Q_DECL_HIDDEN QVariantList intermediateStopsVariant() const;
+    [[nodiscard]] Q_DECL_HIDDEN QList<LoadInfo> loadInformationList() const;
+    Q_DECL_HIDDEN void setLoadInformationList(const QList<LoadInfo> &loadInfo);
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(JourneySection::Modes)
@@ -272,7 +319,7 @@ class KPUBLICTRANSPORT_EXPORT Journey
 {
     KPUBLICTRANSPORT_GADGET(Journey)
     /** Journey sections for consumption by QML. */
-    Q_PROPERTY(QVariantList sections READ sectionsVariant)
+    Q_PROPERTY(QList<KPublicTransport::JourneySection> sections READ sectionsList WRITE setSectionsList)
     /** Departure time of the journey, according to schedule. */
     Q_PROPERTY(QDateTime scheduledDepartureTime READ scheduledDepartureTime STORED false)
     /** @c true if this has real-time data. */
@@ -311,6 +358,9 @@ class KPUBLICTRANSPORT_EXPORT Journey
      */
     Q_PROPERTY(int co2Emission READ co2Emission STORED false)
 
+    /** Maximum occpancy in all journey sections, over all classes. */
+    Q_PROPERTY(KPublicTransport::Load::Category maximumOccupancy READ maximumOccupancy STORED false)
+
 public:
     /** The journey sections. */
     [[nodiscard]] const std::vector<JourneySection>& sections() const;
@@ -335,6 +385,7 @@ public:
 
     [[nodiscard]] int distance() const;
     [[nodiscard]] int co2Emission() const;
+    [[nodiscard]] Load::Category maximumOccupancy() const;
 
     /** Augment line meta data.
      *  @param download if set to @p true, trigger the download of locally missing assets.
@@ -359,7 +410,8 @@ public:
     [[nodiscard]] static std::vector<Journey> fromJson(const QJsonArray &array);
 
 private:
-    [[nodiscard]] QVariantList sectionsVariant() const;
+    [[nodiscard]] Q_DECL_HIDDEN QList<JourneySection> sectionsList() const;
+    Q_DECL_HIDDEN void setSectionsList(const QList<JourneySection> &sections);
 };
 
 }
