@@ -29,8 +29,10 @@
 #include <KPublicTransport/PathModel>
 #include <KPublicTransport/Platform>
 #include <KPublicTransport/RentalVehicle>
+#include <KPublicTransport/Reply>
 #include <KPublicTransport/StopoverQueryModel>
 #include <KPublicTransport/StopoverRequest>
+#include <KPublicTransport/TripRequest>
 #include <KPublicTransport/Vehicle>
 #include <KPublicTransport/VehicleLayoutQueryModel>
 #include <KPublicTransport/VehicleLayoutRequest>
@@ -63,7 +65,6 @@ struct BackendForeign {
 
 struct BackendModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::BackendModel)
     QML_NAMED_ELEMENT(BackendModel)
 };
@@ -112,6 +113,7 @@ struct IndividualTransportForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::IndividualTransport)
     QML_VALUE_TYPE(individualTransport)
+    QML_STRUCTURED_VALUE
 };
 FOREIGN_ENUM_GADGET(IndividualTransport)
 
@@ -119,6 +121,7 @@ struct JourneyForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Journey)
     QML_VALUE_TYPE(journey)
+    QML_STRUCTURED_VALUE
 };
 
 struct JourneyRequestForeign {
@@ -131,7 +134,6 @@ FOREIGN_ENUM_GADGET(JourneyRequest)
 
 struct JourneyQueryModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::JourneyQueryModel)
     QML_NAMED_ELEMENT(JourneyQueryModel)
 };
@@ -140,6 +142,7 @@ struct JourneySectionForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::JourneySection)
     QML_VALUE_TYPE(journeySection)
+    QML_STRUCTURED_VALUE
 };
 FOREIGN_ENUM_GADGET(JourneySection)
 
@@ -147,6 +150,7 @@ struct LineForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Line)
     QML_VALUE_TYPE(line)
+    QML_STRUCTURED_VALUE
 };
 FOREIGN_ENUM_GADGET(Line)
 struct LineMode
@@ -167,6 +171,14 @@ QML_NAMED_ELEMENT(Load)
 QML_FOREIGN_NAMESPACE(KPublicTransport::Load)
 };
 
+struct LoadInfoForeign
+{
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::LoadInfo)
+    QML_VALUE_TYPE(loadInfo)
+    QML_STRUCTURED_VALUE
+};
+
 struct LocationForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Location)
@@ -177,7 +189,6 @@ FOREIGN_ENUM_GADGET(Location)
 
 struct LocationHistoryModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::LocationHistoryModel)
     QML_NAMED_ELEMENT(LocationHistoryModel)
 };
@@ -192,14 +203,12 @@ FOREIGN_ENUM_GADGET(LocationRequest)
 
 struct LocationQueryModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::LocationQueryModel)
     QML_NAMED_ELEMENT(LocationQueryModel)
 };
 
 struct ManagerForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::Manager)
     QML_NAMED_ELEMENT(Manager)
 };
@@ -212,7 +221,6 @@ struct PathForeign {
 
 struct PathModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::PathModel)
     QML_NAMED_ELEMENT(PathModel)
 };
@@ -235,13 +243,22 @@ struct RentalVehicleForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::RentalVehicle)
     QML_VALUE_TYPE(rentalVehicle)
+    QML_STRUCTURED_VALUE
 };
 FOREIGN_ENUM_GADGET(RentalVehicle)
 
+struct ReplyForeign {
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::Reply)
+    QML_NAMED_ELEMENT(Reply)
+    QML_UNCREATABLE("")
+};
+
 struct RouteForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Route)
     QML_VALUE_TYPE(route)
+    QML_STRUCTURED_VALUE
 };
 
 struct StopoverForeign {
@@ -260,11 +277,17 @@ FOREIGN_ENUM_GADGET(StopoverRequest)
 
 struct StopoverQueryModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::StopoverQueryModel)
     QML_NAMED_ELEMENT(StopoverQueryModel)
 };
 
+struct TripRequestForeign {
+    Q_GADGET
+    QML_FOREIGN(KPublicTransport::TripRequest)
+    QML_VALUE_TYPE(tripRequest)
+    QML_STRUCTURED_VALUE
+};
+
 struct VehicleForeign {
     Q_GADGET
     QML_FOREIGN(KPublicTransport::Vehicle)
@@ -283,7 +306,6 @@ FOREIGN_ENUM_GADGET(VehicleLayoutRequest)
 
 struct VehicleLayoutQueryModelForeign {
     Q_GADGET
-    QML_ELEMENT
     QML_FOREIGN(KPublicTransport::VehicleLayoutQueryModel)
     QML_NAMED_ELEMENT(VehicleLayoutQueryModel)
 };
